# Event ID 4720: A user account was created

## Description

This event generates every time a new user object is created. This event generates on domain controllers, member servers, and workstations.

[MS Source](https://github.com/MicrosoftDocs/windows-itpro-docs/blob/master/windows/security/threat-protection/auditing/event-4720.md)

## Event Log Illustration & Event XML

[MS Source](https://github.com/MicrosoftDocs/windows-itpro-docs/blob/master/windows/security/threat-protection/auditing/event-4720.md)

## Data Dictionary

|	Standard Name	|	Field Name	|	Type	|	Description	|	Sample Value	|
|	----------------	|	----------------	|	----------------	|	----------------	|	----------------	|
|	target_user_name	|	TargetUserName	|	string	|	the name of the user account that was created	|	ksmith	|
|	target_user_domain	|	TargetDomainName	|	string	|	domain name of created user account	|	CONTOSO	|
|	target_user_sid	|	TargetSid	|	string	|	SID of created user account. Event Viewer automatically tries to resolve SIDs and show the account name. If the SID cannot be resolved, you will see the source data in the event	|	S-1-5-21-3457937927-2839227994-823803824-6609	|
|	user_sid	|	SubjectUserSid	|	string	|	SID of account that requested the “create user account” operation. Event Viewer automatically tries to resolve SIDs and show the account name. If the SID cannot be resolved, you will see the source data in the event.	|	S-1-5-21-3457937927-2839227994-823803824-1104	|
|	user_name	|	SubjectUserName	|	string	|	the name of the account that requested the “create user account” operation	|	dadmin	|
|	user_domain	|	SubjectDomainName	|	string	|	subject’s domain or computer name	|	CONTOSO	|
|	user_logon_id	|	SubjectLogonId	|	string	|	hexadecimal value that can help you correlate this event with recent events that might contain the same Logon ID	|	0x30dc2	|
|	user_privilege_list	|	PrivilegeList	|	string	|	the list of user privileges which were used during the operation, for example, SeBackupPrivilege. This parameter might not be captured in the event, and in that case appears as “-”.	|	-	|
|	target_user_sam_name	|	SamAccountName	|	string	|	logon name for account used to support clients and servers from previous versions of Windows (pre-Windows 2000 logon name). The value of sAMAccountName attribute of new user object. For example: ksmith. For local account this field contains the name of new user account.	|	ksmith	|
|	target_user_display_name	|	DisplayName	|	string	|	the value of displayName attribute of new user object. It is a name displayed in the address book for a particular account .This is usually the combination of the user's first name, middle initial, and last name. For example, Ken Smith. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. Local accounts contain Full Name attribute in this field, but for new local accounts this field typically has value “\<value not set\>”.	|	Ken Smith	|
|	target_user_principal_name	|	UserPrincipalName	|	string	|	internet-style login name for the account, based on the Internet standard RFC 822. By convention this should map to the account's email name. This parameter contains the value of userPrincipalName attribute of new user object. For example, ksmith@contoso.local. For local users this field is not applicable and has value “-“. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	ksmith@contoso.local	|
|	target_user_home_directory	|	HomeDirectory	|	string	|	user's home directory. If homeDrive attribute is set and specifies a drive letter, homeDirectory should be a UNC path. The path must be a network UNC of the form \\Server\Share\Directory. This parameter contains the value of homeDirectory attribute of new user object. For new local accounts this field typically has value “\<value not set\>”. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. This parameter might not be captured in the event, and in that case appears as “-”.	|	-	|
|	target_user_home_path	|	HomePath	|	string	|	specifies the drive letter to which to map the UNC path specified by homeDirectory account’s attribute. The drive letter must be specified in the form “DRIVE_LETTER:”. For example – “H:”. This parameter contains the value of homeDrive attribute of new user object. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. This parameter might not be captured in the event, and in that case appears as “-”. For new local accounts this field typically has value “\<value not set\>”.	|	-	|
|	target_user_script_path	|	ScriptPath	|	string	|	specifies the path of the account’s logon script. This parameter contains the value of scriptPath attribute of new user object. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. This parameter might not be captured in the event, and in that case appears as “-”. For new local accounts this field typically has value “\<value not set\>”.	|	-	|
|	target_user_profile_path	|	ProfilePath	|	string	|	specifies a path to the account's profile. This value can be a null string, a local absolute path, or a UNC path. This parameter contains the value of profilePath attribute of new user object. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. This parameter might not be captured in the event, and in that case appears as “-”. For new local accounts this field typically has value “\<value not set\>”.	|	-	|
|	target_user_workstations	|	UserWorkstations	|	string	|	contains the list of NetBIOS or DNS names of the computers from which the user can logon. Each computer name is separated by a comma. The name of a computer is the sAMAccountName property of a user object. This parameter contains the value of userWorkstations attribute of new user object. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. This parameter might not be captured in the event, and in that case appears as “-”. For local users this field is not applicable and typically has value “\<value not set\>”.	|	-	|
|	target_user_password_last_set	|	PasswordLastSet	|	date	|	last time the account’s password was modified. For manually created user account, using Active Directory Users and Computers snap-in, this field typically has value “\<never\>”. This parameter contains the value of pwdLastSet attribute of new user object.	|	%%1794	|
|	target_user_account_expires	|	AccountExpires	|	date	|	he date when the account expires. This parameter contains the value of accountExpires attribute of new user object. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. This parameter might not be captured in the event, and in that case appears as “-”. For manually created local and domain user accounts this field typically has value “<never>”.	|	%%1794	|
|	target_user_primary_group_id	|	PrimaryGroupId	|	integer	|	"Relative Identifier (RID) of user’s object primary group. Typically, Primary Group field for new user accounts has the following values: 513 (Domain Users. For local accounts this RID means Users) – for domain and local users. See this article https://support.microsoft.com/en-us/kb/243330 for more information. This parameter contains the value of primaryGroupID attribute of new user object."	|	513	|
|	target_user_allowed_to_delegate	|	AllowedToDelegateTo	|	string	|	the list of SPNs to which this account can present delegated credentials. Can be changed using Active Directory Users and Computers management console in Delegation tab of user account, if this account has at least one SPN registered. This parameter contains the value of AllowedToDelegateTo attribute of new user object. For local user accounts this field is not applicable and typically has value “-“. For new domain user accounts it is typically has value “-“. See description of AllowedToDelegateTo field for “4738(S): A user account was changed.” event for more details.	|	-	|
|	target_user_old_uac_value	|	OldUacValue	|	string	|	specifies flags that control password, lockout, disable/enable, script, and other behavior for the user account. Old UAC value always “0x0” for new user accounts. This parameter contains the previous value of userAccountControl attribute of user object.	|	0x0	|
|	target_user_new_uac_value	|	NewUacValue	|	string	|	specifies flags that control password, lockout, disable/enable, script, and other behavior for the user account. This parameter contains the value of userAccountControl attribute of new user object.	|	0x15	|
|	target_user_account_control	|	UserAccountControl	|	string	|	shows the list of changes in userAccountControl attribute. You will see a line of text for each change. For new user accounts, when the object for this account was created, the userAccountControl value was considered to be “0x0”, and then it was changed from “0x0” to the real value for the account's userAccountControl attribute. See possible values in the table below. In the “User Account Control field text” column, you can see the text that will be displayed in the User Account Control field in 4720 event.	|	%%2080 %%2082 %%2084	|
|	target_user_parameters	|	UserParameters	|	string	|	if you change any setting using Active Directory Users and Computers management console in Dial-in tab of user’s account properties, then you will see \<value changed, but not displayed\> in this field in “4738: A user account was changed.” This parameter might not be captured in the event, and in that case appears as “-”. For new local accounts this field typically has value “\<value not set\>”.	|	-	|
|	target_user_sid_history	|	SidHistory	|	string	|	contains previous SIDs used for the object if the object was moved from another domain. Whenever an object is moved from one domain to another, a new SID is created and becomes the objectSID. The previous SID is added to the sIDHistory property. This parameter contains the value of sIDHistory attribute of new user object. This parameter might not be captured in the event, and in that case appears as “-”.	|	-	|
|	target_user_logon_hours	|	LogonHours	|	string	|	hours that the account is allowed to logon to the domain. The value of logonHours attribute of new user object. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. You will typically see “\<value not set\>” value for new manually created user accounts in event 4720. For new local accounts this field is not applicable and typically has value “All”.	|	%%1793	|