# Event ID 4738: A user account was changed

## Description

This event generates every time user object is changed.

* This event generates on domain controllers, member servers, and workstations.
* For each change, a separate 4738 event will be generated.
* You might see this event without any changes inside, that is, where all Changed Attributes apear as “-“. This usually happens when a change is made to an attribute that is not listed in the event. In this case there is no way to determine which attribute was changed. For example, if the discretionary access control list (DACL) is changed, a 4738 event will generate, but all attributes will be “-“.
* Some changes do not invoke a 4738 event.

[MS Source](https://github.com/MicrosoftDocs/windows-itpro-docs/blob/master/windows/security/threat-protection/auditing/event-4738.md)

## Event Log Illustration & Event XML

[MS Source](https://github.com/MicrosoftDocs/windows-itpro-docs/blob/master/windows/security/threat-protection/auditing/event-4738.md)

## Data Dictionary

|	Standard Name	|	Field Name	|	Type	|	Description	|	Sample Value	|
|	----------------	|	----------------	|	----------------	|	----------------	|	----------------	|
|	dumny	|	Dummy	|	string	|		|	-	|
|	target_user_name	|	TargetUserName	|	string	|	the name of the account that was changed.	|	ksmith	|
|	target_user_domain	|	TargetDomainName	|	string	|	target account’s domain or computer name.	|	CONTOSO	|
|	target_user_sid	|	TargetSid	|	string	|	SID of account that was changed. Event Viewer automatically tries to resolve SIDs and show the account name. If the SID cannot be resolved, you will see the source data in the event.	|	S-1-5-21-3457937927-2839227994-823803824-6609	|
|	user_sid	|	SubjectUserSid	|	string	|	SID of account that requested the “change user account” operation. Event Viewer automatically tries to resolve SIDs and show the account name. If the SID cannot be resolved, you will see the source data in the event.	|	S-1-5-21-3457937927-2839227994-823803824-1104	|
|	user_name	|	SubjectUserName	|	string	|	the name of the account that requested the “change user account” operation.	|	dadmin	|
|	user_domain	|	SubjectDomainName	|	string	|	subject’s domain or computer name.	|	CONTOSO	|
|	user_logon_id	|	SubjectLogonId	|	integer	|	hexadecimal value that can help you correlate this event with recent events that might contain the same Logon ID, for example, “4624: An account was successfully logged on.”	|	0x30dc2	|
|	user_privilege_list	|	PrivilegeList	|	string	|	the list of user privileges which were used during the operation, for example, SeBackupPrivilege. This parameter might not be captured in the event, and in that case appears as “-”. See full list of user privileges in “Table 8. User Privileges.”.	|	-	|
|	target_user_sam_name	|	SamAccountName	|	string	|	logon name for account used to support clients and servers from previous versions of Windows (pre-Windows 2000 logon name). If the value of sAMAccountName attribute of user object was changed, you will see the new value here. For example: ladmin. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_display	|	DisplayName	|	string	|	it is a name, displayed in the address book for a particular account. This is usually the combination of the user's first name, middle initial, and last name. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. If the value of displayName attribute of user object was changed, you will see the new value here. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_principal_name	|	UserPrincipalName	|	string	|	internet-style login name for the account, based on the Internet standard RFC 822. By convention this should map to the account's email name. If the value of userPrincipalName attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field is not applicable and always has “-“ value.	|	-	|
|	target_user_home_directory	|	HomeDirectory	|	string	|	user's home directory. If homeDrive attribute is set and specifies a drive letter, homeDirectory should be a UNC path. The path must be a network UNC of the form \\Server\Share\Directory. If the value of homeDirectory attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_home_path	|	HomePath	|	string	|	specifies the drive letter to which to map the UNC path specified by homeDirectory account’s attribute. The drive letter must be specified in the form “DRIVE_LETTER:”. For example – “H:”. If the value of homeDrive attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_script_path	|	ScriptPath	|	string	|	specifies the path of the account’s logon script. If the value of scriptPath attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_profile_path	|	ProfilePath	|	string	|	specifies a path to the account's profile. This value can be a null string, a local absolute path, or a UNC path. If the value of profilePath attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_workstations	|	UserWorkstations	|	string	|	contains the list of NetBIOS or DNS names of the computers from which the user can logon. Each computer name is separated by a comma. The name of a computer is the sAMAccountName property of a computer object. If the value of userWorkstations attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field is not applicable and always appears as “\<value not set\>.“	|	-	|
|	target_user_password_last_set	|	PasswordLastSet	|	date	|	last time the account’s password was modified. If the value of pwdLastSet attribute of user object was changed, you will see the new value here. For example: 8/12/2015 11:41:39 AM. This value will be changed, for example, after manual user account password reset. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	target_user_account_expires	|	AccountExpires	|	date	|	the date when the account expires. If the value of accountExpires attribute of user object was changed, you will see the new value here. . For example, “9/21/2015 12:00:00 AM”. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. For local accounts, this field always has some value—if the account's attribute was not changed it will contain the current value of the attribute.	|	-	|
|	user_primary_group_id	|	PrimaryGroupId	|	string	|	Relative Identifier (RID) of user’s object primary group.	|	-	|
|	target_user_allowed_to_delegate	|	AllowedToDelegateTo	|	string	|	the list of SPNs to which this account can present delegated credentials. Can be changed using Active Directory Users and Computers management console in Delegation tab of user account, if at least one SPN is registered for user account. If the SPNs list on Delegation tab of a user account was changed, you will see the new SPNs list in AllowedToDelegateTo field (note that you will see the new list instead of changes) of this event. 	|	-	|
|	target_user_old_uac_value	|	OldUacValue	|	string	|	specifies flags that control password, lockout, disable/enable, script, and other behavior for the user account. This parameter contains the previous value of userAccountControl attribute of user object.	|	0x15	|
|	target_user_new_uac_value	|	NewUacValue	|	string	|	specifies flags that control password, lockout, disable/enable, script, and other behavior for the user account. If the value of userAccountControl attribute of user object was changed, you will see the new value here.	|	0x211	|
|	target_user_account_control	|	UserAccountControl	|	string	|	shows the list of changes in userAccountControl attribute. You will see a line of text for each change. See possible values in here: “Table 7. User’s or Computer’s account UAC flags.”. In the “User Account Control field text” column, you can see the text that will be displayed in the User Account Control field in 4738 event.	|	%%2050 %%2089	|
|	target_user_parameters	|	UserParameters	|	string	|	if you change any setting using Active Directory Users and Computers management console in Dial-in tab of user’s account properties, then you will see \<value changed, but not displayed\> in this field. For local accounts, this field is not applicable and always has “\<value not set\>“ value.	|	-	|
|	target_user_sid_history	|	SidHistory	|	string	|	contains previous SIDs used for the object if the object was moved from another domain. Whenever an object is moved from one domain to another, a new SID is created and becomes the objectSID. The previous SID is added to the sIDHistory property. If the value of sIDHistory attribute of user object was changed, you will see the new value here.	|	-	|
|	target_user_logon_hours	|	LogonHours	|	string	|	hours that the account is allowed to logon to the domain. If the value of logonHours attribute of user object was changed, you will see the new value here. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|